==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebToastDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToastDescription } from "./WebToastDescription";
/**
 * @hidden
 */
export let WebToastDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToastDescriptionMetadata extends Base {
        static b(a) {
            if (WebToastDescriptionMetadata.a == null) {
                WebToastDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToastDescriptionMetadata.c(WebToastDescriptionMetadata.a);
            }
            if (a.j(WebToastDescriptionMetadata.a)) {
                return;
            }
            a.y(WebToastDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Toast");
            a.item("__tagNameWC", "String:igc-toast");
            a.item("Open", "Boolean");
            a.item("DisplayTime", "Number:double");
            a.item("KeepOpen", "Boolean");
        }
        static d(a) {
            WebToastDescriptionMetadata.b(a);
            a.aa("WebToast", () => new WebToastDescription());
            a.z("WebToast", WebToastDescriptionMetadata.a);
        }
    }
    WebToastDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToastDescriptionMetadata, 'WebToastDescriptionMetadata');
    WebToastDescriptionMetadata.a = null;
    return WebToastDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebToastDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToastDescription } from "./WebToastDescription";
/**
 * @hidden
 */
export let WebToastDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToastDescriptionMetadata extends Base {
        static b(a) {
            if (WebToastDescriptionMetadata.a == null) {
                WebToastDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToastDescriptionMetadata.c(WebToastDescriptionMetadata.a);
            }
            if (a.k(WebToastDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebToastDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Toast");
            a.item("__tagNameWC", "String:igc-toast");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Open", "Boolean");
            a.item("DisplayTime", "Number:double");
            a.item("KeepOpen", "Boolean");
        }
        static d(a) {
            WebToastDescriptionMetadata.b(a);
            a.ac("WebToast", () => new WebToastDescription());
            a.ab("WebToast", WebToastDescriptionMetadata.a);
        }
    }
    WebToastDescriptionMetadata.$t = /*@__PURE__*/ markType(WebToastDescriptionMetadata, 'WebToastDescriptionMetadata');
    WebToastDescriptionMetadata.a = null;
    return WebToastDescriptionMetadata;
})();
